pub struct OfficeForm {Show 39 fields
pub school: Uuid,
pub registration_number: Option<String>,
pub enrolment_date: Option<NaiveDate>,
pub roll_class: Option<Uuid>,
pub current_year: Option<i32>,
pub house_group: Option<String>,
pub home_care: bool,
pub care_provider_name: String,
pub student_identity: bool,
pub evidence_supplied: bool,
pub in_area: bool,
pub passport_number: i64,
pub issue_country: String,
pub current_visa_subclass: Option<i32>,
pub previous_visa_subclasses: Vec<i32>,
pub authority_code: Option<i64>,
pub medical_plans_copied: bool,
pub personal_plan_copied: bool,
pub air_immunisation_history_copied: bool,
pub immunisation_status: Option<bool>,
pub court_order_copied: bool,
pub parent_not_living_with_student: Option<ParentalResponsibility>,
pub participation_letter_returned: bool,
pub interview_conducted: bool,
pub student_history_assessed: bool,
pub risk_assessment_required: bool,
pub risk_assessment_conducted: Option<bool>,
pub personalised_learning_required: bool,
pub parents_consultation_conducted: bool,
pub planning_completed: bool,
pub violence_management_plan: bool,
pub other_management_plan: bool,
pub health_care_plan: bool,
pub emergency_response_plan: bool,
pub relevant_staff_communication: bool,
pub appication_to_enrol: bool,
pub principal_signature: String,
pub principal_print_name: String,
pub principal_date: NaiveDate,
}Fields
school: Uuidregistration_number: Option<String>enrolment_date: Option<NaiveDate>roll_class: Option<Uuid>current_year: Option<i32>house_group: Option<String>home_care: boolcare_provider_name: Stringstudent_identity: boolevidence_supplied: boolin_area: boolpassport_number: i64issue_country: Stringcurrent_visa_subclass: Option<i32>previous_visa_subclasses: Vec<i32>medical_plans_copied: boolpersonal_plan_copied: boolair_immunisation_history_copied: boolimmunisation_status: Option<bool>court_order_copied: boolparent_not_living_with_student: Option<ParentalResponsibility>participation_letter_returned: boolinterview_conducted: boolstudent_history_assessed: boolrisk_assessment_required: boolrisk_assessment_conducted: Option<bool>personalised_learning_required: boolparents_consultation_conducted: boolplanning_completed: boolviolence_management_plan: boolother_management_plan: boolhealth_care_plan: boolemergency_response_plan: boolrelevant_staff_communication: boolappication_to_enrol: boolprincipal_signature: Stringprincipal_print_name: Stringprincipal_date: NaiveDateTrait Implementations
Sourceimpl Clone for OfficeForm
impl Clone for OfficeForm
Sourcefn clone(&self) -> OfficeForm
fn clone(&self) -> OfficeForm
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OfficeForm
impl Debug for OfficeForm
Sourceimpl<'de> Deserialize<'de> for OfficeForm
impl<'de> Deserialize<'de> for OfficeForm
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> FromSql<'a> for OfficeForm
impl<'a> FromSql<'a> for OfficeForm
Sourcefn from_sql(
_type: &Type,
buf: &'a [u8],
) -> Result<OfficeForm, Box<dyn Error + Sync + Send>>
fn from_sql( _type: &Type, buf: &'a [u8], ) -> Result<OfficeForm, Box<dyn Error + Sync + Send>>
Creates a new value of this type from a buffer of data of the specified
Postgres
Type in its binary format. Read moreSourcefn accepts(type_: &Type) -> bool
fn accepts(type_: &Type) -> bool
Determines if a value of this type can be created from the specified
Postgres
Type.Sourceimpl PartialEq for OfficeForm
impl PartialEq for OfficeForm
Sourceimpl Serialize for OfficeForm
impl Serialize for OfficeForm
Sourceimpl ToSql for OfficeForm
impl ToSql for OfficeForm
Sourcefn to_sql(
&self,
_type: &Type,
buf: &mut BytesMut,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn to_sql( &self, _type: &Type, buf: &mut BytesMut, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
Converts the value of
self into the binary format of the specified
Postgres Type, appending it to out. Read moreSourcefn accepts(type_: &Type) -> bool
fn accepts(type_: &Type) -> bool
Determines if a value of this type can be converted to the specified
Postgres
Type.Sourcefn to_sql_checked(
&self,
ty: &Type,
out: &mut BytesMut,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn to_sql_checked( &self, ty: &Type, out: &mut BytesMut, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
An adaptor method used internally by Rust-Postgres. Read more
Sourcefn encode_format(&self, _ty: &Type) -> Format
fn encode_format(&self, _ty: &Type) -> Format
Specify the encode format
impl StructuralPartialEq for OfficeForm